@@ -31,6 +31,7 @@ from .ProjectHolder import ProjectHolder
 from .Version import Version
 from .argparse_version import VersionAction
 from .utils import download_file, ApiCredentialsError, BadProjectError, rpm_installed_version
+from six.moves.urllib.parse import urlparse
 
 log = logging.getLogger(__name__)
 __self__ = "dvershinin/lastversion"
@@ -92,6 +93,7 @@ def latest(repo, output_format='version', pre_ok=False, assets_filter=None,
             upstream_name = None
             current_version = None
             spec_repo = None
+            spec_url = None
             for l in f.readlines():
                 if l.startswith('%global lastversion_repo'):
                     spec_repo = l.split(' ')[2].strip()
@@ -101,16 +103,20 @@ def latest(repo, output_format='version', pre_ok=False, assets_filter=None,
                     upstream_name = l.split(' ')[2].strip()
                 elif l.startswith('Name:'):
                     name = l.split('Name:')[1].strip()
+                elif l.startswith('URL:'):
+                    spec_url = l.split('URL:')[1].strip()
                 elif l.startswith('%global upstream_version '):
                     current_version = l.split(' ')[2].strip()
                     # influences %spec_tag to use %upstream_version instead of %version
                     repo_data['module_of'] = True
                 elif l.startswith('Version:') and not current_version:
                     current_version = l.split('Version:')[1].strip()
-            if not upstream_github and not spec_repo:
-                log.critical('Neither %upstream_github nor %lastversion_repo macros were found. '
-                             'Please prepare your spec file using instructions: '
-                             'https://lastversion.getpagespeed.com/spec-preparing.html')
+            if spec_url:
+                spec_host = urlparse(spec_url).hostname
+                if spec_host in ['github.com'] and not upstream_github and not spec_repo:
+                    log.warning('Neither %upstream_github nor %lastversion_repo macros were found. '
+                                 'Please prepare your spec file using instructions: '
+                                 'https://lastversion.getpagespeed.com/spec-preparing.html')
             if not current_version:
                 log.critical('Did not find neither Version: nor %upstream_version in the spec file')
                 sys.exit(1)
@@ -130,9 +136,11 @@ def latest(repo, output_format='version', pre_ok=False, assets_filter=None,
             if upstream_github:
                 repo = "{}/{}".format(upstream_github, repo_data['name'])
                 log.info('Discovered GitHub repo {} from .spec file'.format(repo))
-            else:
+            elif spec_repo:
                 repo = spec_repo
                 log.info('Discovered explicit repo {} from .spec file'.format(repo))
+            elif spec_url:
+                repo = spec_url
 
     if (not at or '/' in repo) and at != 'helm_chart':
         # find the right hosting for this repo
@@ -170,10 +178,10 @@ def latest(repo, output_format='version', pre_ok=False, assets_filter=None,
     if output_format in ['json', 'dict']:
         if output_format == 'dict':
             release['version'] = version
-            release['tag_date'] = release['tag_date']
         else:
             release['version'] = str(version)
-            release['tag_date'] = str(release['tag_date'])
+            if 'tag_date' in release:
+                release['tag_date'] = str(release['tag_date'])
         release['v_prefix'] = tag.startswith("v")
         version_macro = 'upstream_version' if 'module_of' in repo_data else 'version'
         version_macro = '%{{{}}}'.format(version_macro)
